==> server_client_comm-0.1.6.tar.gz: lib/src/sccomm.dart <==
library sccomm;

import 'dart:convert';

import 'package:dson/dson.dart';

part 'typesOfSame.dart';


///Where everything in this sccomm library is,
///See:
/// * [SocketMessage.shrinkT] for encoding
/// * [SocketMessage.expandT] for decoding
class SocketMessage {
  String jsonMessage;
  var data;
  ///shrink the [data] into a json message
  /// * See also [SocketMessage.expandT] for the opposite transformation
  static shrinkT(var data,[String type]) => new SocketMessage(data).shrink(type:type);
  ///expand the [data] into a 'thing'
  /// * See also [SocketMessage.shrinkT] for the opposite transformation
  static expandT(String data) => new SocketMessage(data).expand();
  shrink({String type}) {
    type = ((type != null) ? type : typeSerializer(data.runtimeType));
    Map jsonMessageTemp = {"type": type};
    //Start the madness!
    //Goal: turn data into a string!
    if (type == 'run command') {
      jsonMessageTemp['data'] = SocketMessage.shrinkT(data);
    } else if (type == "Map") {
      //type is Map
      jsonMessageTemp["data"] = new Map.fromIterables(
          (data as Map).keys.map(SocketMessage.shrinkT),
          (data as Map).values.map(SocketMessage.shrinkT));
    } else if (type == "List") {
      //type is List
      jsonMessageTemp["data"] = (data as List).map(SocketMessage.shrinkT).toList();
    } else if (classMirrors != null &&
        (() {
          //is type in classMirrors
          for (Type tpe in classMirrors.keys) {
            if (type == tpe.toString()) return true;
          }
          return false;
        }())) {
      //serialize it using toJson()
      jsonMessageTemp["data"] = toJson(data);
    } else {
      jsonMessageTemp["data"] = JSON.encode(data);
    }

    //Madness end!
    jsonMessage = JSON.encode(jsonMessageTemp);
    return jsonMessage;
  }

  expand() {
    var dataTemp = JSON.decode(jsonMessage);
    if (dataTemp["type"] == "List") {
      //data is a List (Reverse of shrink)
      data = (dataTemp["data"] as List).map(SocketMessage.expandT).toList();
    } else if (dataTemp["type"] == "Set") {
      //data is a List (Reverse of shrink)
      data = (dataTemp["data"] as Set).map(SocketMessage.expandT).toSet();
    } else if (dataTemp["type"] == "Map") {
      //data is a Map (Reverse of shrink)
      data = new Map.fromIterables(
          (dataTemp["data"] as Map).keys.map(SocketMessage.expandT),
          (dataTemp["data"] as Map).values.map(SocketMessage.expandT));
    } else if (dataTemp["type"] == "run command") {
      //it's a servercommand, duh!
      data = dataTemp;
      return data;
    } else if (classMirrors != null &&
        () {
          //if type is in classMirrors, return true, otherwise, return false
          for (Type tpe in classMirrors.keys) {
            if (tpe.toString() == dataTemp["type"]) return true;
          }
          return false;
        }()) {
      //use fromJson
      data = fromJson(dataTemp["data"], () {
        for (Type tpe in classMirrors.keys) {
          if (tpe.toString() == dataTemp["type"]) return tpe;
        }
      }());
    } else {
      data = JSON.decode(dataTemp["data"]);
    }
    return data;
  }

  SocketMessage(this.data);
  SocketMessage.fromJson(this.jsonMessage);
  String toString() => shrink();
}

==> server_client_comm-0.1.7.tar.gz: lib/src/sccomm.dart <==
library sccomm;

import 'dart:convert';

import 'package:dson/dson.dart';

part 'typesOfSame.dart';


///Where everything in this sccomm library is,
///See:
/// * [SocketMessage.shrinkT] for encoding
/// * [SocketMessage.expandT] for decoding
class SocketMessage {
  String jsonMessage;
  var data;
  ///shrink the [data] into a json message
  /// * See also [SocketMessage.expandT] for the opposite transformation
  static shrinkT(var data,[String type]) => new SocketMessage(data).shrink(type:type);
  ///expand the [data] into a 'thing'
  /// * See also [SocketMessage.shrinkT] for the opposite transformation
  static expandT(String data) => new SocketMessage.fromJson(data).expand();
  shrink({String type}) {
    type = ((type != null) ? type : typeSerializer(data.runtimeType));
    Map jsonMessageTemp = {"type": type};
    //Start the madness!
    //Goal: turn data into a string!
    if (type == 'run command') {
      jsonMessageTemp['data'] = SocketMessage.shrinkT(data);
    } else if (type == "Map") {
      //type is Map
      jsonMessageTemp["data"] = new Map.fromIterables(
          (data as Map).keys.map(SocketMessage.shrinkT),
          (data as Map).values.map(SocketMessage.shrinkT));
    } else if (type == "List") {
      //type is List
      jsonMessageTemp["data"] = (data as List).map(SocketMessage.shrinkT).toList();
    } else if (classMirrors != null &&
        (() {
          //is type in classMirrors
          for (Type tpe in classMirrors.keys) {
            if (type == tpe.toString()) return true;
          }
          return false;
        }())) {
      //serialize it using toJson()
      jsonMessageTemp["data"] = toJson(data);
    } else {
      jsonMessageTemp["data"] = JSON.encode(data);
    }

    //Madness end!
    jsonMessage = JSON.encode(jsonMessageTemp);
    return jsonMessage;
  }

  expand() {
    var dataTemp = JSON.decode(jsonMessage);
    if (dataTemp["type"] == "List") {
      //data is a List (Reverse of shrink)
      data = (dataTemp["data"] as List).map(SocketMessage.expandT).toList();
    } else if (dataTemp["type"] == "Set") {
      //data is a List (Reverse of shrink)
      data = (dataTemp["data"] as Set).map(SocketMessage.expandT).toSet();
    } else if (dataTemp["type"] == "Map") {
      //data is a Map (Reverse of shrink)
      data = new Map.fromIterables(
          (dataTemp["data"] as Map).keys.map(SocketMessage.expandT),
          (dataTemp["data"] as Map).values.map(SocketMessage.expandT));
    } else if (dataTemp["type"] == "run command") {
      //it's a servercommand, duh!
      data = dataTemp;
      return data;
    } else if (classMirrors != null &&
        () {
          //if type is in classMirrors, return true, otherwise, return false
          for (Type tpe in classMirrors.keys) {
            if (tpe.toString() == dataTemp["type"]) return true;
          }
          return false;
        }()) {
      //use fromJson
      data = fromJson(dataTemp["data"], () {
        for (Type tpe in classMirrors.keys) {
          if (tpe.toString() == dataTemp["type"]) return tpe;
        }
      }());
    } else {
      data = JSON.decode(dataTemp["data"]);
    }
    return data;
  }

  SocketMessage(this.data);
  SocketMessage.fromJson(this.jsonMessage);
  String toString() => shrink();
}
